import { getTokenInfo } from './getTokenInfo.js';
import { Permissions } from './permissions.js';
export async function checkPermission(request, permission) {
    const accessToken = request.headers.get('Authorization');
    if (!accessToken) {
        throw new Error('Request is missing authentication data');
    }
    const { subjectType } = await getTokenInfo(accessToken);
    const roles = getMatchingRolesForPermission(permission);
    if (!roles.includes(subjectType)) {
        throw new Error('Insufficient permissions');
    }
}
function getMatchingRolesForPermission(permission) {
    switch (permission) {
        case Permissions.Anyone: {
            return ['VISITOR', 'MEMBER', 'USER'];
        }
        case Permissions.SiteMember: {
            return ['MEMBER', 'USER'];
        }
        case Permissions.Admin: {
            return ['USER'];
        }
    }
}
