"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkPermission = checkPermission;
const getTokenInfo_js_1 = require("./getTokenInfo.js");
const permissions_js_1 = require("./permissions.js");
async function checkPermission(request, permission) {
    const accessToken = request.headers.get('Authorization');
    if (!accessToken) {
        throw new Error('Request is missing authentication data');
    }
    const { subjectType } = await (0, getTokenInfo_js_1.getTokenInfo)(accessToken);
    const roles = getMatchingRolesForPermission(permission);
    if (!roles.includes(subjectType)) {
        throw new Error('Insufficient permissions');
    }
}
function getMatchingRolesForPermission(permission) {
    switch (permission) {
        case permissions_js_1.Permissions.Anyone: {
            return ['VISITOR', 'MEMBER', 'USER'];
        }
        case permissions_js_1.Permissions.SiteMember: {
            return ['MEMBER', 'USER'];
        }
        case permissions_js_1.Permissions.Admin: {
            return ['USER'];
        }
    }
}
