"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createClient = createClient;
const serialize_error_1 = require("serialize-error");
const checkPermissions_js_1 = require("./checkPermissions.js");
const utils_js_1 = require("./utils.js");
function createClient(webMethods) {
    return {
        async parseRequest(request) {
            const url = new URL(request.url);
            const parts = (0, utils_js_1.extractUrlParts)(url.pathname);
            if (!parts) {
                throw new Error('Invalid request URL');
            }
            return parts;
        },
        async processRequest(request, devMode = false) {
            const parts = (0, utils_js_1.extractUrlParts)(request.url);
            if (!parts) {
                return {
                    response: new Response('invalid request', { status: 400 }),
                    hasError: false,
                };
            }
            const body = (await request.json());
            if (!(0, utils_js_1.isRequestBodyValid)(body)) {
                return {
                    response: new Response('invalid request', { status: 400 }),
                    hasError: false,
                };
            }
            const loadWebMethodFile = webMethods[`/${parts.filename}`];
            try {
                if (!loadWebMethodFile) {
                    throw new Error(`Error loading web module ${parts.filename}: Cannot find module '${parts.filename}'`);
                }
                const webMethod = (await loadWebMethodFile())[parts.methodname];
                if (!webMethod) {
                    throw new Error(`Error loading function from web module ${parts.filename}: function '${parts.methodname}' not found`);
                }
                await (0, checkPermissions_js_1.checkPermission)(request, webMethod.permission);
                return {
                    response: Response.json({
                        result: await webMethod(...body),
                    }),
                    hasError: false,
                };
            }
            catch (error) {
                const serializedError = (0, serialize_error_1.serializeError)(error, { maxDepth: 1 });
                return {
                    response: Response.json({
                        result: devMode || !(error instanceof Error)
                            ? serializedError
                            : {
                                ...serializedError,
                                message: utils_js_1.productionErrorMessage,
                                stack: utils_js_1.productionErrorMessage,
                            },
                        exception: true,
                    }),
                    error,
                    hasError: true,
                };
            }
        },
    };
}
